/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "vnconversation.h"

void vnConversationInit(vnconversation_t *convo, font_t *font) {
  convo->textCount = 0x00;
  convo->textCurrent = 0xFF;
  convo->timeline = 0;
  convo->delayStart = 0;
  vnTextBoxInit(&convo->textbox, font);
}

void vnConversationNext(vnconversation_t *convo) {
  vnconversationtext_t *text;
  convo->textCurrent++;
  if(convo->textCurrent >= convo->textCount) return;
  convo->delayStart = convo->timeline;
  text = convo->texts + convo->textCurrent;

  if(text->text != NULL) {
    vnTextBoxSetText(&convo->textbox, text->text);
  }
}

vnconversationtext_t * vnConversationAdd(vnconversation_t *conversation) {
  vnconversationtext_t *text = conversation->texts + conversation->textCount;
  conversation->textCount++;
  text->text = NULL;
  return text;
}

void vnConversationUpdate(vnconversation_t *convo, engine_t *engine) {
  vnconversationtext_t *text;

  // Get the current text
  convo->timeline += engine->time.delta;
  if(convo->textCurrent >= convo->textCount) return;

  text = convo->texts + convo->textCurrent;
  if(text->text != NULL) {
    vnTextBoxUpdate(&convo->textbox, engine);
    if(convo->textbox.state & VN_TEXTBOX_STATE_CLOSED) {
      vnConversationNext(convo);
    }
  } else if(text->delay > 0) {
    if(convo->delayStart + text->delay <= convo->timeline) {
      vnConversationNext(convo);
    }
  }
}

void vnConversationRender(vnconversation_t *convo, shader_t *shader) {
  vnTextBoxRender(&convo->textbox, shader);
}

void vnConversationDispose(vnconversation_t *convo) {
  vnTextBoxDispose(&convo->textbox);
}